==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/CustomRuleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.CustomRuleArgs.builder
import com.pulumi.azurenative.network.kotlin.enums.ActionType
import com.pulumi.azurenative.network.kotlin.enums.CustomRuleEnabledState
import com.pulumi.azurenative.network.kotlin.enums.RuleType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Defines contents of a web application rule
 * @property action Describes what action to be applied when rule matches.
 * @property enabledState Describes if the custom rule is in enabled or disabled state. Defaults to Enabled if not specified.
 * @property matchConditions List of match conditions.
 * @property name Describes the name of the rule.
 * @property priority Describes priority of the rule. Rules with a lower value will be evaluated before rules with a higher value.
 * @property rateLimitDurationInMinutes Time window for resetting the rate limit count. Default is 1 minute.
 * @property rateLimitThreshold Number of allowed requests per client within the time window.
 * @property ruleType Describes type of rule.
 */
public data class CustomRuleArgs(
    public val action: Output<Either<String, ActionType>>,
    public val enabledState: Output<Either<String, CustomRuleEnabledState>>? = null,
    public val matchConditions: Output<List<FrontDoorMatchConditionArgs>>,
    public val name: Output<String>? = null,
    public val priority: Output<Int>,
    public val rateLimitDurationInMinutes: Output<Int>? = null,
    public val rateLimitThreshold: Output<Int>? = null,
    public val ruleType: Output<Either<String, RuleType>>,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.CustomRuleArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.CustomRuleArgs =
        com.pulumi.azurenative.network.inputs.CustomRuleArgs.builder()
            .action(
                action.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .enabledState(
                enabledState?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .matchConditions(
                matchConditions.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .name(name?.applyValue({ args0 -> args0 }))
            .priority(priority.applyValue({ args0 -> args0 }))
            .rateLimitDurationInMinutes(rateLimitDurationInMinutes?.applyValue({ args0 -> args0 }))
            .rateLimitThreshold(rateLimitThreshold?.applyValue({ args0 -> args0 }))
            .ruleType(
                ruleType.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [CustomRuleArgs].
 */
@PulumiTagMarker
public class CustomRuleArgsBuilder internal constructor() {
    private var action: Output<Either<String, ActionType>>? = null

    private var enabledState: Output<Either<String, CustomRuleEnabledState>>? = null

    private var matchConditions: Output<List<FrontDoorMatchConditionArgs>>? = null

    private var name: Output<String>? = null

    private var priority: Output<Int>? = null

    private var rateLimitDurationInMinutes: Output<Int>? = null

    private var rateLimitThreshold: Output<Int>? = null

    private var ruleType: Output<Either<String, RuleType>>? = null

    /**
     * @param value Describes what action to be applied when rule matches.
     */
    @JvmName("osxstifvphxfvjpi")
    public suspend fun action(`value`: Output<Either<String, ActionType>>) {
        this.action = value
    }

    /**
     * @param value Describes if the custom rule is in enabled or disabled state. Defaults to Enabled if not specified.
     */
    @JvmName("exsuswxuvfygvxin")
    public suspend fun enabledState(`value`: Output<Either<String, CustomRuleEnabledState>>) {
        this.enabledState = value
    }

    /**
     * @param value List of match conditions.
     */
    @JvmName("frrrrcffqwvndlnt")
    public suspend fun matchConditions(`value`: Output<List<FrontDoorMatchConditionArgs>>) {
        this.matchConditions = value
    }

    @JvmName("crgewceoukhguswa")
    public suspend fun matchConditions(vararg values: Output<FrontDoorMatchConditionArgs>) {
        this.matchConditions = Output.all(values.asList())
    }

    /**
     * @param values List of match conditions.
     */
    @JvmName("mavlkwlrkrjbykck")
    public suspend fun matchConditions(values: List<Output<FrontDoorMatchConditionArgs>>) {
        this.matchConditions = Output.all(values)
    }

    /**
     * @param value Describes the name of the rule.
     */
    @JvmName("sktmprttiqfppuln")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Describes priority of the rule. Rules with a lower value will be evaluated before rules with a higher value.
     */
    @JvmName("vdqhoydnlwbmvysq")
    public suspend fun priority(`value`: Output<Int>) {
        this.priority = value
    }

    /**
     * @param value Time window for resetting the rate limit count. Default is 1 minute.
     */
    @JvmName("sxmyrfmgkutfnmcw")
    public suspend fun rateLimitDurationInMinutes(`value`: Output<Int>) {
        this.rateLimitDurationInMinutes = value
    }

    /**
     * @param value Number of allowed requests per client within the time window.
     */
    @JvmName("rlyocelclrqfkdkn")
    public suspend fun rateLimitThreshold(`value`: Output<Int>) {
        this.rateLimitThreshold = value
    }

    /**
     * @param value Describes type of rule.
     */
    @JvmName("erdmyilmegmdepqu")
    public suspend fun ruleType(`value`: Output<Either<String, RuleType>>) {
        this.ruleType = value
    }

    /**
     * @param value Describes what action to be applied when rule matches.
     */
    @JvmName("jihrrlbqbapjclcg")
    public suspend fun action(`value`: Either<String, ActionType>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value Describes what action to be applied when rule matches.
     */
    @JvmName("exdmfmfwjuuhnten")
    public fun action(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ActionType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value Describes what action to be applied when rule matches.
     */
    @JvmName("boendulrywtraygp")
    public fun action(`value`: ActionType) {
        val toBeMapped = Either.ofRight<String, ActionType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value Describes if the custom rule is in enabled or disabled state. Defaults to Enabled if not specified.
     */
    @JvmName("pfbhnctjmibxinpl")
    public suspend fun enabledState(`value`: Either<String, CustomRuleEnabledState>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enabledState = mapped
    }

    /**
     * @param value Describes if the custom rule is in enabled or disabled state. Defaults to Enabled if not specified.
     */
    @JvmName("fflxfqxkjnatfxob")
    public fun enabledState(`value`: String) {
        val toBeMapped = Either.ofLeft<String, CustomRuleEnabledState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.enabledState = mapped
    }

    /**
     * @param value Describes if the custom rule is in enabled or disabled state. Defaults to Enabled if not specified.
     */
    @JvmName("tsvgoiikmjermpmh")
    public fun enabledState(`value`: CustomRuleEnabledState) {
        val toBeMapped = Either.ofRight<String, CustomRuleEnabledState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.enabledState = mapped
    }

    /**
     * @param value List of match conditions.
     */
    @JvmName("mmttepehcvbdhlcl")
    public suspend fun matchConditions(`value`: List<FrontDoorMatchConditionArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.matchConditions = mapped
    }

    /**
     * @param argument List of match conditions.
     */
    @JvmName("defgseyyrywfjwcc")
    public suspend
    fun matchConditions(argument: List<suspend FrontDoorMatchConditionArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            FrontDoorMatchConditionArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.matchConditions = mapped
    }

    /**
     * @param argument List of match conditions.
     */
    @JvmName("erqmluuxjcradgka")
    public suspend fun matchConditions(
        vararg
        argument: suspend FrontDoorMatchConditionArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            FrontDoorMatchConditionArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.matchConditions = mapped
    }

    /**
     * @param argument List of match conditions.
     */
    @JvmName("lmiqssxagmydhpec")
    public suspend
    fun matchConditions(argument: suspend FrontDoorMatchConditionArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            FrontDoorMatchConditionArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.matchConditions = mapped
    }

    /**
     * @param values List of match conditions.
     */
    @JvmName("hxcqjeqojogdgxck")
    public suspend fun matchConditions(vararg values: FrontDoorMatchConditionArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.matchConditions = mapped
    }

    /**
     * @param value Describes the name of the rule.
     */
    @JvmName("wbfphughrtcxxkmh")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Describes priority of the rule. Rules with a lower value will be evaluated before rules with a higher value.
     */
    @JvmName("outpnlqhuarydywy")
    public suspend fun priority(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.priority = mapped
    }

    /**
     * @param value Time window for resetting the rate limit count. Default is 1 minute.
     */
    @JvmName("qjbwqlylednlpypn")
    public suspend fun rateLimitDurationInMinutes(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.rateLimitDurationInMinutes = mapped
    }

    /**
     * @param value Number of allowed requests per client within the time window.
     */
    @JvmName("tguyhasfsxejpbdc")
    public suspend fun rateLimitThreshold(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.rateLimitThreshold = mapped
    }

    /**
     * @param value Describes type of rule.
     */
    @JvmName("qmaliwhebgfaifnc")
    public suspend fun ruleType(`value`: Either<String, RuleType>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ruleType = mapped
    }

    /**
     * @param value Describes type of rule.
     */
    @JvmName("lstavssyhtmoxmyd")
    public fun ruleType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, RuleType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ruleType = mapped
    }

    /**
     * @param value Describes type of rule.
     */
    @JvmName("eijquiqdirwsyxhg")
    public fun ruleType(`value`: RuleType) {
        val toBeMapped = Either.ofRight<String, RuleType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ruleType = mapped
    }

    internal fun build(): CustomRuleArgs = CustomRuleArgs(
        action = action ?: throw PulumiNullFieldException("action"),
        enabledState = enabledState,
        matchConditions = matchConditions ?: throw PulumiNullFieldException("matchConditions"),
        name = name,
        priority = priority ?: throw PulumiNullFieldException("priority"),
        rateLimitDurationInMinutes = rateLimitDurationInMinutes,
        rateLimitThreshold = rateLimitThreshold,
        ruleType = ruleType ?: throw PulumiNullFieldException("ruleType"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/CustomRuleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.CustomRuleArgs.builder
import com.pulumi.azurenative.network.kotlin.enums.ActionType
import com.pulumi.azurenative.network.kotlin.enums.CustomRuleEnabledState
import com.pulumi.azurenative.network.kotlin.enums.RuleType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Defines contents of a web application rule
 * @property action Describes what action to be applied when rule matches.
 * @property enabledState Describes if the custom rule is in enabled or disabled state. Defaults to Enabled if not specified.
 * @property matchConditions List of match conditions.
 * @property name Describes the name of the rule.
 * @property priority Describes priority of the rule. Rules with a lower value will be evaluated before rules with a higher value.
 * @property rateLimitDurationInMinutes Time window for resetting the rate limit count. Default is 1 minute.
 * @property rateLimitThreshold Number of allowed requests per client within the time window.
 * @property ruleType Describes type of rule.
 */
public data class CustomRuleArgs(
    public val action: Output<Either<String, ActionType>>,
    public val enabledState: Output<Either<String, CustomRuleEnabledState>>? = null,
    public val matchConditions: Output<List<FrontDoorMatchConditionArgs>>,
    public val name: Output<String>? = null,
    public val priority: Output<Int>,
    public val rateLimitDurationInMinutes: Output<Int>? = null,
    public val rateLimitThreshold: Output<Int>? = null,
    public val ruleType: Output<Either<String, RuleType>>,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.CustomRuleArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.CustomRuleArgs =
        com.pulumi.azurenative.network.inputs.CustomRuleArgs.builder()
            .action(
                action.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .enabledState(
                enabledState?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .matchConditions(
                matchConditions.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .name(name?.applyValue({ args0 -> args0 }))
            .priority(priority.applyValue({ args0 -> args0 }))
            .rateLimitDurationInMinutes(rateLimitDurationInMinutes?.applyValue({ args0 -> args0 }))
            .rateLimitThreshold(rateLimitThreshold?.applyValue({ args0 -> args0 }))
            .ruleType(
                ruleType.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [CustomRuleArgs].
 */
@PulumiTagMarker
public class CustomRuleArgsBuilder internal constructor() {
    private var action: Output<Either<String, ActionType>>? = null

    private var enabledState: Output<Either<String, CustomRuleEnabledState>>? = null

    private var matchConditions: Output<List<FrontDoorMatchConditionArgs>>? = null

    private var name: Output<String>? = null

    private var priority: Output<Int>? = null

    private var rateLimitDurationInMinutes: Output<Int>? = null

    private var rateLimitThreshold: Output<Int>? = null

    private var ruleType: Output<Either<String, RuleType>>? = null

    /**
     * @param value Describes what action to be applied when rule matches.
     */
    @JvmName("ivwdvnlkuvjprvpa")
    public suspend fun action(`value`: Output<Either<String, ActionType>>) {
        this.action = value
    }

    /**
     * @param value Describes if the custom rule is in enabled or disabled state. Defaults to Enabled if not specified.
     */
    @JvmName("woxiqoafmmfnnnwk")
    public suspend fun enabledState(`value`: Output<Either<String, CustomRuleEnabledState>>) {
        this.enabledState = value
    }

    /**
     * @param value List of match conditions.
     */
    @JvmName("wsasmjcyrbxesgbt")
    public suspend fun matchConditions(`value`: Output<List<FrontDoorMatchConditionArgs>>) {
        this.matchConditions = value
    }

    @JvmName("buggvvhpexenybth")
    public suspend fun matchConditions(vararg values: Output<FrontDoorMatchConditionArgs>) {
        this.matchConditions = Output.all(values.asList())
    }

    /**
     * @param values List of match conditions.
     */
    @JvmName("goxgchljuypsjtur")
    public suspend fun matchConditions(values: List<Output<FrontDoorMatchConditionArgs>>) {
        this.matchConditions = Output.all(values)
    }

    /**
     * @param value Describes the name of the rule.
     */
    @JvmName("ebmqjffehitbykry")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Describes priority of the rule. Rules with a lower value will be evaluated before rules with a higher value.
     */
    @JvmName("aqoytushoqnxdwof")
    public suspend fun priority(`value`: Output<Int>) {
        this.priority = value
    }

    /**
     * @param value Time window for resetting the rate limit count. Default is 1 minute.
     */
    @JvmName("bxuiveajagfxbyca")
    public suspend fun rateLimitDurationInMinutes(`value`: Output<Int>) {
        this.rateLimitDurationInMinutes = value
    }

    /**
     * @param value Number of allowed requests per client within the time window.
     */
    @JvmName("eqqabrvjgvmbfson")
    public suspend fun rateLimitThreshold(`value`: Output<Int>) {
        this.rateLimitThreshold = value
    }

    /**
     * @param value Describes type of rule.
     */
    @JvmName("dlvfjesqwsxfjkke")
    public suspend fun ruleType(`value`: Output<Either<String, RuleType>>) {
        this.ruleType = value
    }

    /**
     * @param value Describes what action to be applied when rule matches.
     */
    @JvmName("ymnnogbrnvmyrsbn")
    public suspend fun action(`value`: Either<String, ActionType>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value Describes what action to be applied when rule matches.
     */
    @JvmName("byrmdxwiamoyjbmv")
    public fun action(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ActionType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value Describes what action to be applied when rule matches.
     */
    @JvmName("ixjloaqvchydipaw")
    public fun action(`value`: ActionType) {
        val toBeMapped = Either.ofRight<String, ActionType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value Describes if the custom rule is in enabled or disabled state. Defaults to Enabled if not specified.
     */
    @JvmName("dsqnqdleljktqeur")
    public suspend fun enabledState(`value`: Either<String, CustomRuleEnabledState>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enabledState = mapped
    }

    /**
     * @param value Describes if the custom rule is in enabled or disabled state. Defaults to Enabled if not specified.
     */
    @JvmName("hhyurevnrogdavcb")
    public fun enabledState(`value`: String) {
        val toBeMapped = Either.ofLeft<String, CustomRuleEnabledState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.enabledState = mapped
    }

    /**
     * @param value Describes if the custom rule is in enabled or disabled state. Defaults to Enabled if not specified.
     */
    @JvmName("uxwifavuldputigg")
    public fun enabledState(`value`: CustomRuleEnabledState) {
        val toBeMapped = Either.ofRight<String, CustomRuleEnabledState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.enabledState = mapped
    }

    /**
     * @param value List of match conditions.
     */
    @JvmName("tncakplpobrmptvv")
    public suspend fun matchConditions(`value`: List<FrontDoorMatchConditionArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.matchConditions = mapped
    }

    /**
     * @param argument List of match conditions.
     */
    @JvmName("jnfdofouatbhoett")
    public suspend
    fun matchConditions(argument: List<suspend FrontDoorMatchConditionArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            FrontDoorMatchConditionArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.matchConditions = mapped
    }

    /**
     * @param argument List of match conditions.
     */
    @JvmName("pmitpxchotmedtqr")
    public suspend fun matchConditions(
        vararg
        argument: suspend FrontDoorMatchConditionArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            FrontDoorMatchConditionArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.matchConditions = mapped
    }

    /**
     * @param argument List of match conditions.
     */
    @JvmName("bajyaprmthxgitym")
    public suspend
    fun matchConditions(argument: suspend FrontDoorMatchConditionArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            FrontDoorMatchConditionArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.matchConditions = mapped
    }

    /**
     * @param values List of match conditions.
     */
    @JvmName("yfdqdipnkvlnygnj")
    public suspend fun matchConditions(vararg values: FrontDoorMatchConditionArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.matchConditions = mapped
    }

    /**
     * @param value Describes the name of the rule.
     */
    @JvmName("rxeavmakeqswfugn")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Describes priority of the rule. Rules with a lower value will be evaluated before rules with a higher value.
     */
    @JvmName("dlwwymvfyhudtaei")
    public suspend fun priority(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.priority = mapped
    }

    /**
     * @param value Time window for resetting the rate limit count. Default is 1 minute.
     */
    @JvmName("drltnfqtmsqenumf")
    public suspend fun rateLimitDurationInMinutes(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.rateLimitDurationInMinutes = mapped
    }

    /**
     * @param value Number of allowed requests per client within the time window.
     */
    @JvmName("edkjntvagqusjxuh")
    public suspend fun rateLimitThreshold(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.rateLimitThreshold = mapped
    }

    /**
     * @param value Describes type of rule.
     */
    @JvmName("taumpcgubohywfvg")
    public suspend fun ruleType(`value`: Either<String, RuleType>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ruleType = mapped
    }

    /**
     * @param value Describes type of rule.
     */
    @JvmName("thvbtytoixrswiwp")
    public fun ruleType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, RuleType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ruleType = mapped
    }

    /**
     * @param value Describes type of rule.
     */
    @JvmName("rkemakvnddwvryie")
    public fun ruleType(`value`: RuleType) {
        val toBeMapped = Either.ofRight<String, RuleType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ruleType = mapped
    }

    internal fun build(): CustomRuleArgs = CustomRuleArgs(
        action = action ?: throw PulumiNullFieldException("action"),
        enabledState = enabledState,
        matchConditions = matchConditions ?: throw PulumiNullFieldException("matchConditions"),
        name = name,
        priority = priority ?: throw PulumiNullFieldException("priority"),
        rateLimitDurationInMinutes = rateLimitDurationInMinutes,
        rateLimitThreshold = rateLimitThreshold,
        ruleType = ruleType ?: throw PulumiNullFieldException("ruleType"),
    )
}
